extensions [array]

; In this model each employer hires one worker, then another employer plays and the process continues until all positions are filled.
; Expected values of network indeces can be calculated by another code expectedvalueofpairwisesimilarity.nlogo by Károly Takács.


globals [discrimination-index average-discrimination adjusted-current adjusted-discrimination
  variance-discrimination ave-var-discrimination
  mean-discrimination ave-mean-discrimination disc-ini meandi-ini vardi-ini 
  expected-segregation pairwise-similarity labormarketsegregation-index
  isthereany correlation-index correlation-index2 average-correlation-index average-correlation-index2]

breed [employers employer]
breed [workers worker]
undirected-link-breed [friends friend]  ;friends among employers
undirected-link-breed [professionals professional] ;professional experience of employer with worker
undirected-link-breed [hirings hiring]  ;actual hiring of worker by employer
undirected-link-breed [acrosses across] ;friendship links between employers and workers
undirected-link-breed [fellows fellow] ;friendship links (referrals) between workers

employers-own [quality blues greens blue-gossip green-gossip aspiration-i hired-blues
  discrimination-i] ;aspiration-i is the aspiration level for the given employer, by default there are no aspirations 
    ;discrimination-i is the discrimination-index for the given employer                   
workers-own [quality hired aspiration] 
professionals-own [age responsible]
friends-own [similarity]

to setup
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
  set-default-shape turtles "circle"
  set average-correlation-index 0
  set average-discrimination 0
  set adjusted-discrimination 0
  set variance-discrimination 0
  set ave-var-discrimination 0
  set mean-discrimination 0
  set ave-mean-discrimination 0
  ; set expected-segregation 0 ; if there are no business ties
  ; set expected-segregation 0.6470196335078534 ; this is the value that is calculated by  expectedvalueofpairwisesimilarity.nlogo for density 0.133333 and 15 employers and 5 to-fill
  set expected-segregation 0.5470979805534935  ; this is the value that is calculated by  expectedvalueofpairwisesimilarity.nlogo for density 0.133333 and 15 employers and 6 to-fill
  set labormarketsegregation-index 0
  employer-setup
  worker-setup
end

to employer-setup
  if network-type != "matrix entry" [
   create-employers n-employers [
    setxy (random-pxcor) (max-pycor - random 10)
    set color red
    set shape "house"
    set size 2
    set blues initial-reputation
    set greens initial-reputation
    set hired-blues 0
    set discrimination-i 0
    set quality random 20
    set label quality
    if aspiration-levels = "none" [set aspiration-i 0]
    if aspiration-levels = "average" [set aspiration-i 9.5]
    if aspiration-levels = "initial reputation" [set aspiration-i initial-reputation]
    if aspiration-levels = "randomly distributed" [set aspiration-i random 191 / 10]
    if aspiration-levels = "quality correlated" [
      let level quality + (2 * random 2 - 1) * random employer-quality-correlation-aspiration-level  ; +/- random delta
      if level > 19 [set level 19]
      if level < 0 [set level 0]
      set aspiration-i level]
   ]
  ]
  if network-type = "random" [random-network]
  if network-type = "star" [star-network]
  if network-type = "regular" [regular-network]
  if network-type = "2 segments" [segmented-network]
  if network-type = "matrix entry" [read-matrix]
  ask friends [set similarity 0]
  ; repeat 10 [layout-spring employers friends 5 0.1 4
  ;  display]
end

to random-network
  let tie-count 0
  while [round (link-probability * (n-employers - 1)  * n-employers / 2) > tie-count] [
    ask one-of employers [
      let to-link one-of other employers 
      if not member? to-link friend-neighbors [
        create-friend-with to-link
        set tie-count tie-count + 1
      ]
    ]
  ]
end

to star-network
  ; with this option, centralized networks are created
  ; the most centralized network is the star
  ; for the sake of simplicity, all the first l requested links direct to a single agent
  ; if more than n-1 links are requested, then remaining links are random
  let tie-needed  round (link-probability * (n-employers - 1)  * n-employers / 2) 
  ifelse tie-needed <= n-employers - 1  
    [ask one-of employers [
      create-friends-with n-of tie-needed other employers]
     ]
    [let tie-count n-employers - 1
     ask one-of employers [
       create-friends-with other employers]
     while [tie-needed > tie-count] [
      ask one-of employers [
        let to-link one-of other employers
        if not member? to-link friend-neighbors [
          create-friend-with to-link
          set tie-count tie-count + 1
        ]
       ]
     ]
    ]
end

to regular-network
  ; with this option, regular networks are created
  ; first a circle, then nodes with distance 2 are connected
  ; then nodes at distance 3 in the original circle are connected
  let tie-count 0
  let agent-counter 0
  let step 0
  let tie-needed  round (link-probability * (n-employers - 1)  * n-employers / 2) 
  while [tie-needed > tie-count] [
    while [(tie-needed > tie-count) and (n-employers > agent-counter)] [
      if (tie-count >= step * n-employers) and (tie-count < (step + 1) * n-employers - step - 1) [
        ask employer agent-counter [
          create-friend-with employer (agent-counter + step + 1)]
      ]
      if (tie-count >= (step + 1) * n-employers - step - 1) and (tie-count <= (step + 1) * n-employers) [
        ask employer agent-counter [
          create-friend-with employer (step + agent-counter + 1 - n-employers)]
      ]
      set tie-count tie-count + 1
      set agent-counter agent-counter + 1
    ]
    set step step + 1
    set agent-counter 0
  ]
end

to segmented-network
  ; with this option, as long as link-probability allows, 2 components of equal size are created
  ; this is possible if tie-count <= max-ties - (roundup(n/2)*rounddown(n/2))
  ; within each component, ties are drawn randomly and with equal probability
  ; note that due to the random drawing, there might be more than 2 components
  ; note that for odd numbers of nodes, 1 component is larger
  ; if two components of equal size cannot be created, then 2 components of unequal size are created
  ; in case of a high link-probability: tie-count > max-ties - (n-1), there will just be 1 component
  let tie-count 0
  let tie-needed  round (link-probability * (n-employers - 1)  * n-employers / 2) 
  let largest-component round (n-employers / 2)
  while [tie-needed > ((n-employers - 1)  * n-employers / 2) - largest-component * (n-employers - largest-component)] [
    set largest-component largest-component + 1
    ]
  while [tie-needed > tie-count] [
    ask one-of employers [
      ifelse who < largest-component ; who runs from 0 ... largest-component-1, hence this is the largest component
        [let to-link one-of other employers with [who < largest-component]
         if not member? to-link friend-neighbors [
            create-friend-with to-link
            set tie-count tie-count + 1
          ]
        ]
        [if n-employers - largest-component > 1 [
          let to-link one-of other employers with [who >= largest-component] 
          if not member? to-link friend-neighbors [
            create-friend-with to-link
            set tie-count tie-count + 1
            ]
          ]
        ]
    ]
  ]
end

to read-matrix
  ; enter a friendship matrix of employers manually
   create-employers 15 [
    setxy (random-pxcor) (max-pycor - random 10)
    set color red
    set shape "house"
    set size 2
    set blues initial-reputation
    set greens initial-reputation
    set hired-blues 0
    set discrimination-i 0
    if aspiration-levels = "none" [set aspiration-i 0]
    if aspiration-levels = "average" [set aspiration-i 9.5]
    if aspiration-levels = "initial reputation" [set aspiration-i initial-reputation]
    if aspiration-levels = "randomly distributed" [set aspiration-i random 191 / 10]
   ]
  ; it is now currently set to two regular segments (one circle of 7 nodes and one line of 8 nodes, density of 0.133333333333
  ask employer 0 [create-friend-with employer 1]
  ask employer 1 [create-friend-with employer 2]
  ask employer 2 [create-friend-with employer 3]
  ask employer 3 [create-friend-with employer 4]
  ask employer 4 [create-friend-with employer 5]
  ask employer 5 [create-friend-with employer 6]
  ask employer 6 [create-friend-with employer 0]
  ask employer 7 [create-friend-with employer 8]
  ask employer 8 [create-friend-with employer 9]
  ask employer 9 [create-friend-with employer 10]
  ask employer 10 [create-friend-with employer 11]
  ask employer 11 [create-friend-with employer 12]
  ask employer 12 [create-friend-with employer 13]
  ask employer 13 [create-friend-with employer 14]
end

to worker-setup
  
  
  ifelse worker-aspiration-level = "quality correlated" [
      ;let level quality + (2 * random 2 - 1) * random worker-quality-correlation-aspiration-level  ; +/- random delta
      ;if level > 19 [set level 19]
      ;if level < 0 [set level 0]
      ;set aspiration level
      
      
      ;;
      ;;
      ;;
      ;; GENERATING DATA WITH SPECIFIED CORRELATION
      ;;
      ;;
      ;;
      
      let seq1 array:from-list n-values n-workers [0]
      let seq2 array:from-list n-values n-workers [0]
      let seq1std array:from-list n-values n-workers [0]
      let seq2std array:from-list n-values n-workers [0]
      let seqZ array:from-list n-values n-workers [0]
      let desired-correlation worker-quality-aspiration-correlation-index
 
      let i 0
      let summ1 0
      let summ2 0
      let mean1 0
      let mean2 0
      
      let sumofsquare1 0
      let sumofsquare2 0
      let squaredsum1 0
      let squaredsum2 0
      let devstd1 0
      let devstd2 0
 
      
      ; GET 2 RANDOM SEQUENCES
      
      set i 0
      while [i < n-workers] [
        array:set seq1 i random 20
        array:set seq2 i random 20
        set i i + 1
      ]
      
      ; COMPUTE MEAN AND STDDEVIATIONS
      
      ;mean
      set i 0
      set summ1 0
      set summ2 0
      while [i < n-workers] [
        set summ1 summ1 + (array:item seq1 i)
        set summ2 summ2 + (array:item seq2 i)
        set i i + 1
      ]
      set mean1 summ1 / n-workers
      set mean2 summ2 / n-workers
      
      ;dev standard
      set i 0
      while [i < n-workers] [
        set sumofsquare1 sumofsquare1 + (array:item seq1 i) * (array:item seq1 i)
        set sumofsquare2 sumofsquare2 + (array:item seq2 i) * (array:item seq2 i)
        set squaredsum1 squaredsum1 + (array:item seq1 i)
        set squaredsum2 squaredsum2 + (array:item seq2 i)
        set i i + 1
      ]
      set squaredsum1 squaredsum1 * squaredsum1
      set squaredsum2 squaredsum2 * squaredsum2
      set devstd1 1 / n-workers * sqrt ( n-workers * sumofsquare1 - squaredsum1 )
      set devstd2 1 / n-workers * sqrt ( n-workers * sumofsquare2 - squaredsum2 )
      
      type "seq1: " print seq1
      type "mean1: " print mean1
      type "devstd1: " print devstd1
      type "seq2: " print seq2
      type "mean2: " print mean2
      type "devstd2: " print devstd2
      
      ; STANDARDIZE
      
      set i 0
      while [i < n-workers] [
        array:set seq1std i ((array:item seq1 i) - mean1) / devstd1
        array:set seq2std i ((array:item seq2 i) - mean2) / devstd2
        set i i + 1
      ]
      type "seq1std: " print seq1std
      type "seq2std: " print seq2std
      
      ;calc a
      let a desired-correlation / (sqrt(1 - desired-correlation * desired-correlation))
      type "a: " print a
      
      ;calc seqZ
      
      set i 0
      while [i < n-workers] [
        array:set seqZ i a * (array:item seq1std i) + (array:item seq2std i)
        set i i + 1
      ]
      type "seqZ: " print seqZ
      
      ;re-standardize seqZ
      set i 0
      while [i < n-workers] [
        array:set seqZ i (array:item seqZ i) * devstd1 + mean1
        set i i + 1
      ]
      type "seqZrestd: " print seqZ
      
      
      ;TRANSLATE seqZ
      set i 0
      let minval 0
      while [i < n-workers] [
        if (array:item seqZ i) < minval
        [set minval (array:item seqZ i) ]
        set i i + 1
      ]
      set i 0
      while [i < n-workers] [
        array:set seqZ i ((array:item seqZ i) - minval)
        set i i + 1
      ]
      type "seqZtranslated: " print seqZ
      
      ;normalize seqZ
      set i 0
      let maxval 0
      let v 0
      while [i < n-workers] [
        ifelse (array:item seqZ i) < 0
        [set v -1 * (array:item seqZ i) ]
        [set v (array:item seqZ i) ]
        if v > maxval
        [set maxval v ]
        set i i + 1
      ]
      set i 0
      while [i < n-workers] [
        array:set seqZ i ((array:item seqZ i) / maxval) * 19
        set i i + 1
      ]
      type "seqZnormalized: " print seqZ
      print "--------------------------------------"
      type "desired-correlation -> " print desired-correlation
      type "seq1       : " print seq1
      
      ;floor seqZ
      set i 0
      while [i < n-workers] [
        array:set seqZ i floor (array:item seqZ i)
        set i i + 1
      ]
      type "seqZfloored: " print seqZ
      

      ; WORKERS CREATION
      
      set i 0
      while [i < n-workers] [
        create-workers 1 [
          ifelse i mod 2 = 0 [set color green] [set color blue]
          ifelse color = green
          [setxy (random max-pxcor) (1 + random (max-pycor - 12))]
          [setxy (- random max-pxcor) (1 + random (max-pycor - 12))]
          set quality (array:item seq1 i)
          set aspiration (array:item seqZ i)
          set size (quality / 20 + 0.5)
          set label aspiration
        ]
        set i i + 1
      ]
  
  ]
  
  
  [create-workers n-workers [
    ifelse who < (n-workers / 2) + n-employers [set color green] [set color blue]
    ifelse color = green
      [setxy (random max-pxcor) (1 + random (max-pycor - 12))]
      [setxy (- random max-pxcor) (1 + random (max-pycor - 12))]
    set quality random 20
    ifelse color = green
      [ifelse quality < 19 - group-differences 
        [set quality group-differences + random 20]
        [set quality 19]]
      [ifelse quality > group-differences
        [set quality (random 20) - group-differences]
        [set quality 0]]          
    if worker-aspiration-level = "random" [set aspiration random 20]
    
    set size (quality / 20 + 0.5)
    set label aspiration
  ]]
  let across-count 0
  while [round (friends-across * n-employers * n-workers) > across-count] [
    ask one-of employers [
      let to-across one-of workers
      if not member? to-across across-neighbors [
        create-across-with to-across
        set across-count across-count + 1    
      ]
    ]  
  ]
  ask acrosses [set color violet]
  if referral-density > 0 [referral-network]    
end

to referral-network
  ; this is a procedure that creates a network of workers SEGREGATED by color
  ; with this option, as long as referral-density allows, 2 components of equal size are created
  ; this is possible if tie-count <= max-ties - (roundup(n/2)*rounddown(n/2))
  ; within each component, ties are drawn randomly and with equal probability
  ; note that due to the random drawing, there might be more than 2 components
  ; note that for odd numbers of nodes, 1 component is larger
  ; if two components of equal size cannot be created, then 2 components of unequal size are created
  ; in case of a high referral-density: tie-count > max-ties - (n-1), there will just be 1 component
  let tie-count 0
  let tie-needed  round (referral-density * (n-workers - 1)  * n-workers / 2) 
  let largest-component round (n-workers / 2)
  while [tie-needed > ((n-workers - 1)  * n-workers / 2) - largest-component * (n-workers - largest-component)] [
    set largest-component largest-component + 1
    ]
  while [tie-needed > tie-count] [
    ask one-of workers [
      ifelse who < largest-component ; who runs from 0 ... largest-component-1, hence this is the largest component
        [let to-link one-of other workers with [who < largest-component]
         if not member? to-link fellow-neighbors [
            create-fellow-with to-link
            set tie-count tie-count + 1
          ]
        ]
        [if n-workers - largest-component > 1 [
          let to-link one-of other workers with [who >= largest-component] 
          if not member? to-link fellow-neighbors [
            create-fellow-with to-link
            set tie-count tie-count + 1
            ]
          ]
        ]
    ]
  ]
end


; end of setup part *********************************************************************


to go
  tick
  update-links
  employer-actions
  do-plots
  analyze-correlation
  if ticks = 1 [
    set disc-ini average-discrimination
    set meandi-ini ave-mean-discrimination
    set vardi-ini ave-var-discrimination
  ]
  if ticks >= time-horizon [
    set average-discrimination average-discrimination / ticks
    set adjusted-discrimination adjusted-discrimination / ticks
    set ave-mean-discrimination ave-mean-discrimination / ticks
    set ave-var-discrimination ave-var-discrimination / ticks
    set labormarketsegregation-index labormarketsegregation-index / ticks
    set average-correlation-index average-correlation-index / ticks
    set average-correlation-index2 average-correlation-index2 / ticks
    
    ;type "Average discrimination-index: " print average-discrimination
    ;type "Average mean discrimination: " print ave-mean-discrimination
    ;type "Average variance of discrimination: " print ave-var-discrimination
    ;type "Average labor market segregation: " print labormarketsegregation-index
    ;type "Average correlation index: " print average-correlation-index
    stop
  ]
end

to update-links
  let profhired false
  ask professionals [
    set age age + 1
    set color red
    if age > max-link-age [die]
    if responsible = true [die] ; very cruel: if somebody gave a bad recommendation, that tie is deleted
  ]
  ask hirings [die]  
end

to employer-actions
  ask workers [set hired false]
  
    let filled 0
    while [filled < to-fill] [
      ask employers [hire-worker]
      set filled filled + 1
    ]
    while [filled < to-fill + new-employment] [
      ask employers [check-groupreputations]
      set filled filled + 1
    ]
  
  ask employers [
    set hired-blues count hiring-neighbors with [color = blue]
    ; let hired-i-blues (hired-blues / (count workers with [color = blue])) if unequal group sizes are introduced
    let hired-i-greens (count hiring-neighbors with [color = green]) ; / (count workers with [color = green]) if unequal group sizes are introduced
    
    
    ifelse new-disc-index
      ;; NEW INDEX
      [set discrimination-i (abs (hired-i-greens - hired-blues)) / (hired-blues + hired-i-greens)]
      ;; OLD INDEX
      [
        ifelse hired-blues > hired-i-greens
          [set discrimination-i (1 - hired-i-greens / hired-blues)]
          [set discrimination-i (1 - hired-blues / hired-i-greens)]
      ]

    update-reputations
   ]
  
  if group-gossip > 0 [
    ask employers [
      set blue-gossip blues
      set green-gossip greens
      if any? friend-neighbors [
        set blue-gossip ((1 - group-gossip) * blues + group-gossip * mean [blues] of friend-neighbors)
        set green-gossip ((1 - group-gossip) * greens + group-gossip * mean [greens] of friend-neighbors)
      ]
    ]
    ask employers [
      set blues blue-gossip
      set greens green-gossip
    ]
  ]  
end

to hire-worker
  
  let empquality quality
  
  ; checks among known unemployed workers
  let known-workers professional-neighbors with [hired = false] ; known-workers is an agentset
  let best-group max list (greens) (blues)
  if any? known-workers [
    let best-worker nobody
    ifelse dualmatching = true 
    [set best-worker max-one-of known-workers with [aspiration <= empquality] [quality]]
    [set best-worker max-one-of known-workers [quality]]
    
    ifelse best-worker = nobody [] [
    if [quality] of best-worker > best-group and [quality] of best-worker >= aspiration-i [
      ask best-worker [set hired true]
      create-professional-with best-worker 
      ask professional-with best-worker [
        set age 0
        set responsible false]
      create-hiring-with best-worker [set color yellow]
      stop
    ]]    
  ]
    
  ; checks among unemployed friends with unknown quality
  let known-friends-listed [who] of across-neighbors with [hired = false] ;this creates a list
  if not empty? known-friends-listed [
    let we-count 0
    while [we-count < length known-friends-listed - 1] [
      let we-talk-about item we-count known-friends-listed
      ifelse professional-neighbor? worker we-talk-about 
        [set we-count we-count + 1] ; excludes professional neighbors
        [set we-count we-count + 1
        ask worker we-talk-about [set hired true]
        create-professional-with worker we-talk-about 
        ask professional-with worker we-talk-about [
          set age 0
          set responsible false]
        create-hiring-with worker we-talk-about [set color yellow]
        stop
        ]
      ]
    ]
         
  ; checks among workers known by friend employers
  let extra-workers no-turtles
  let my-friends [who] of friend-neighbors
  foreach my-friends [
    ask employer ? [ 
      let my-workers professional-neighbors with [hired = false]
      set extra-workers (turtle-set extra-workers my-workers)
    ] 
  ]   
  if any? extra-workers [
    let best-worker max-one-of extra-workers [quality]
    ; note that a check for professional-neighbor is not necessary here, because professional-neighbors who satisfy
    ; the following condition have already been selected in "check among known unemployed workers"
    if [quality] of best-worker > best-group and [quality] of best-worker >= aspiration-i [
      ask best-worker [set hired true]
      create-professional-with best-worker 
      ask professional-with best-worker [
        set age 0
        set responsible false]
      create-hiring-with best-worker [set color yellow]
      stop
    ]    
  ]
 
  
  ; this part is out-commented in this version, because we do not analyze this in the current version of the paper
  ; checks among across friends of friend employers with unknown quality
;  let extra-acrosses no-turtles
;  set my-friends [who] of friend-neighbors
;  foreach my-friends [
;    ask employer ? [
;      let my-acrosses across-neighbors with [hired = false]
;      if any? my-acrosses [
;        let seconds-listed [who] of my-acrosses
;        let ac-count 0
;        while [ac-count < length seconds-listed - 1] [
;          let ac-talk-about item ac-count seconds-listed
;          ifelse professional-neighbor? worker ac-talk-about
;            [set ac-count ac-count + 1]
;            [set ac-count ac-count + 1
;             set extra-acrosses (turtle-set extra-acrosses worker ac-talk-about)] 
;        ]
;      ]
;    ]
;  ]
;  if any? extra-acrosses [
;    let referred-chosen one-of extra-acrosses
;    ask referred-chosen [set hired true]
;    create-professional-with referred-chosen
;    ask professional-with referred-chosen [
;      set age 0
;      set responsible false]
;    create-hiring-with referred-chosen [set color yellow]
;    stop
;  ]

  ; checks worker-referrals 
  ; note that professional neighbors give referrals and not across-friends
  ; makes maximum of 2n of professional-neighbors attempts, if not sucessful, does not request recommendations from workers
  if round (referral-density * (n-workers - 1)  * n-workers / 2) > 0  [ ; if referral-density > 0
    let attempt 0
    let attempting 0
    let found false
    let referred-worker no-turtles
    while [attempt < 2 * count professional-neighbors] [
      let recommender one-of professional-neighbors
      ask recommender 
       [ifelse any? fellow-neighbors with [hired = false] 
         [set referred-worker one-of fellow-neighbors with [hired = false]
          set attempting 0
          while [attempting < 2 * count fellow-neighbors with [hired = false]]
           [ifelse member? referred-worker known-workers 
             [set referred-worker one-of fellow-neighbors with [hired = false]
              set attempting attempting + 1]
             [set found true
              set attempting  2 * count fellow-neighbors with [hired = false]]
           ] 
          if found = true 
           [ask referred-worker [set hired true]
            set attempt 2 * count professional-neighbors] ; if somebody found, give up searching
         ]
         [set attempt attempt + 1] ; keep on searching if there are no unemployed fellow-neighbors for this recommender
       if (found = false) and (attempting =  2 * count fellow-neighbors with [hired = false]) [set attempt attempt + 1] 
          ; this is the case if all fellow-neighbors are known-workers / attempting reached limit without success
       ]
      if found = true [ 
        create-professional-with referred-worker 
        ask professional-with referred-worker [
          set age 0
          set responsible false]
        create-hiring-with referred-worker [set color yellow]
        if [quality] of referred-worker < aspiration-i [
          ask professional-with recommender [
            set responsible true]
          ]
        stop
        ]
     ]
   ]
          
  check-groupreputations ; select from group with a higher reputation
end

to check-groupreputations
  set isthereany false
  ; check among the group with the highest reputation
  ifelse greens = blues
  [
    ifelse random 2 > 0
     [check-greens]
     [check-blues]
  ]
  [    
    ifelse greens > blues
     [check-greens]
     [check-blues]
  ]
end

to check-greens
  ifelse (count workers with [color = green and hired = false] > count professional-neighbors with [color = green and hired = false])
  [let to-hire one-of workers with [color = green and hired = false]
    while [member? to-hire professional-neighbors] [set to-hire one-of workers with [color = green and hired = false]]
    ask to-hire [set hired true]
    create-professional-with to-hire [
      set age 0
    ]
    create-hiring-with to-hire [set color yellow]         
  ]
  [ifelse isthereany = false 
    [set isthereany true
     check-blues
    ]
    [check-hiredblues]
  ]
end

to check-blues
  ifelse (count workers with [color = blue and hired = false] > count professional-neighbors with [color = blue and hired = false])
  [let to-hire one-of workers with [color = blue and hired = false]
    while [member? to-hire professional-neighbors] [set to-hire one-of workers with [color = blue and hired = false]]
    ask to-hire [set hired true]
    create-professional-with to-hire [
      set age 0
    ]
    create-hiring-with to-hire [set color yellow]         
  ]
  [ifelse isthereany = false 
    [set isthereany true
     check-greens
    ]
    [check-hiredgreens]
  ]  
end

to check-hiredgreens
  let empquality quality
  ifelse any? workers with [color = green and hired = false and aspiration <= empquality]
  [
    let to-hire one-of workers with [color = green and hired = false]
    ask to-hire [set hired true]
    create-professional-with to-hire [
      set age 0
    ]
    create-hiring-with to-hire [set color yellow]        
  ]
  [check-hiredblues]  
end

to check-hiredblues
  ifelse any? workers with [color = blue and hired = false]
  [
    let to-hire one-of workers with [color = blue and hired = false]
    ask to-hire [set hired true]
    create-professional-with to-hire [
      set age 0
    ]
    create-hiring-with to-hire [set color yellow]         
  ]
  [check-hiredgreens]    
end

to update-reputations
  if any? professional-neighbors with [color = blue]
     [set blues (top-bias * max [quality] of professional-neighbors with [color = blue] + bottom-bias * min [quality] of professional-neighbors with [color = blue] + (1 - top-bias - bottom-bias) *  mean [quality] of professional-neighbors with [color = blue])
     ]
  if any? professional-neighbors with [color = green]
     [set greens (top-bias * max [quality] of professional-neighbors with [color = green] + bottom-bias * min [quality] of professional-neighbors with [color = green] + (1 - top-bias - bottom-bias) *  mean [quality] of professional-neighbors with [color = green])
     ]           
end  


to do-plots
  let hired-blue-proportion (count workers with [hired = true and color = blue]) ; / (count workers with [color = blue]) if unequal group sizes are allowed
  let hired-green-proportion (count workers with [hired = true and color = green]) ; / (count workers with [color = green]) if unequal group sizes are allowed
  
  if new-disc-index [set discrimination-index ((abs (hired-green-proportion - hired-blue-proportion)) / (hired-green-proportion + hired-blue-proportion))]
  
  
  ifelse hired-blue-proportion > hired-green-proportion
    [if new-disc-index = false [set discrimination-index (1 - hired-green-proportion / hired-blue-proportion)] ;; OLD INDEX
     if  (to-fill * n-employers >= n-workers / 2) and (hired-blue-proportion > to-fill * n-employers - n-workers / 2)
       [set adjusted-current  (1 - (hired-green-proportion - to-fill * n-employers + n-workers / 2) / (hired-blue-proportion -  to-fill * n-employers + n-workers / 2) ) ] ]
    [if new-disc-index = false [set discrimination-index (1 - hired-blue-proportion / hired-green-proportion)] ;; OLD INDEX
     if  to-fill * n-employers >= n-workers / 2  and (hired-green-proportion > to-fill * n-employers - n-workers / 2)
       [set adjusted-current  (1 - (hired-blue-proportion - to-fill * n-employers + n-workers / 2) / (hired-green-proportion -  to-fill * n-employers + n-workers / 2) ) ] ]
  if (hired-blue-proportion = to-fill * n-employers - n-workers / 2) or (hired-green-proportion = to-fill * n-employers - n-workers / 2)
    [set adjusted-current 1]
  if to-fill * n-employers < n-workers / 2
    [set adjusted-current discrimination-index]
  set average-discrimination average-discrimination + discrimination-index
  set adjusted-discrimination adjusted-discrimination + adjusted-current
  
  set mean-discrimination mean [discrimination-i] of employers
  set ave-mean-discrimination ave-mean-discrimination + mean-discrimination
  set variance-discrimination variance [discrimination-i] of employers
  set ave-var-discrimination ave-var-discrimination + variance-discrimination
  
  ask friends [
    let oneend [hired-blues] of end1
    let otherend [hired-blues] of end2
    set similarity (((to-fill / 2) - abs (oneend - otherend)) / (to-fill / 2))  
  ]
  ifelse any? friends [set pairwise-similarity mean [similarity] of friends] [set pairwise-similarity 0]
  let  divergence-from-expectation 0
  ifelse pairwise-similarity > expected-segregation
    [set divergence-from-expectation (pairwise-similarity - expected-segregation) / (1 - expected-segregation)]
    [set divergence-from-expectation (pairwise-similarity - expected-segregation) / (-1 - expected-segregation)]
  set labormarketsegregation-index labormarketsegregation-index + divergence-from-expectation
  
  set-current-plot "Number of hired workers"  
  set-current-plot-pen "blues"
  plot mean [hired-blues] of employers
  set-current-plot-pen "greens"
  plot to-fill - (mean [hired-blues] of employers)  
  set-current-plot "Group reputation"  
  set-current-plot-pen "blues"
  plot mean [blues] of employers
  set-current-plot-pen "greens"
  plot mean [greens] of employers  
  
  set-current-plot "Correlation empl-quality worker-aspiration" 
  plot correlation-index
  
  set-current-plot "Correlation empl-quality worker-quality" 
  plot correlation-index2
end

to analyze-correlation
  
  ;; GET 2 datasets
  let nofitems n-employers * to-fill
  let emp-qual array:from-list n-values nofitems [0]
  let work-asp array:from-list n-values nofitems [0]
  let work-qual array:from-list n-values nofitems [0]
  
  ;print("nofitems")
  ;print(nofitems)
  
  let i 0
  let currentquality 0
  ask employers [
    set currentquality quality
    ask hiring-neighbors [
      array:set emp-qual i currentquality
      array:set work-asp i aspiration
      array:set work-qual i quality
      set i i + 1
    ]
  ]
  
  ;print emp-qual
  ;print work-asp
  ;print work-qual
  
  ;;COMPUTE COVARIANCE
  
  ;mean emp quality
  let summ 0
  set i 0
  while [i < nofitems] [
    set summ summ + (array:item emp-qual i)
    set i i + 1
  ]
  let mean-emp-qual summ / nofitems
  
  ;mean worker aspiration
  set summ 0
  set i 0
  while [i < nofitems] [
    set summ summ + (array:item work-asp i)
    set i i + 1
  ]
  let mean-work-asp summ / nofitems
  
  ;mean worker quality
  set summ 0
  set i 0
  while [i < nofitems] [
    set summ summ + (array:item work-qual i)
    set i i + 1
  ]
  let mean-work-qual summ / nofitems
  
  ;covariance
  set summ 0
  set i 0
  while [i < nofitems] [
    set summ summ + (array:item emp-qual i - mean-emp-qual) * (array:item work-asp i - mean-work-asp)
    set i i + 1
  ]
  
  let covariance 1 / nofitems * summ
  
  ;covariance 2
  set summ 0
  set i 0
  while [i < nofitems] [
    set summ summ + (array:item emp-qual i - mean-emp-qual) * (array:item work-qual i - mean-work-qual)
    set i i + 1
  ]
  
  let covariance2 1 / nofitems * summ
  
  ;print("covariance")
  ;print(covariance)
  
  ;print("covariance2")
  ;print(covariance2)
  
  ;;COMPUTE PRODUCT OF STD DEVIATIONS
  
  ;first std deviation
  let sumofsquare 0
  set i 0
  while [i < nofitems] [
    set sumofsquare sumofsquare + (array:item emp-qual i) * (array:item emp-qual i)
    set i i + 1
  ]
  let squaredsum 0
  set i 0
  while [i < nofitems] [
    set squaredsum squaredsum + (array:item emp-qual i)
    set i i + 1
  ]
  set squaredsum squaredsum * squaredsum
  let emp-qual-std-dev 1 / nofitems * sqrt ( nofitems * sumofsquare - squaredsum )
  
  ; second std deviation
  set sumofsquare 0
  set i 0
  while [i < nofitems] [
    set sumofsquare sumofsquare + (array:item work-asp i) * (array:item work-asp i)
    set i i + 1
  ]
  set squaredsum 0
  set i 0
  while [i < nofitems] [
    set squaredsum squaredsum + (array:item work-asp i)
    set i i + 1
  ]
  set squaredsum squaredsum * squaredsum
  let work-asp-std-dev 1 / nofitems * sqrt ( nofitems * sumofsquare - squaredsum )
  
  ; third std deviation
  set sumofsquare 0
  set i 0
  while [i < nofitems] [
    set sumofsquare sumofsquare + (array:item work-qual i) * (array:item work-qual i)
    set i i + 1
  ]
  set squaredsum 0
  set i 0
  while [i < nofitems] [
    set squaredsum squaredsum + (array:item work-qual i)
    set i i + 1
  ]
  set squaredsum squaredsum * squaredsum
  let work-qual-std-dev 1 / nofitems * sqrt ( nofitems * sumofsquare - squaredsum )
  
  ;product of std deviations
  let prod-of-std-deviations emp-qual-std-dev * work-asp-std-dev
  
  ;product of std deviations 2
  let prod-of-std-deviations2 emp-qual-std-dev * work-qual-std-dev
  
  
  ;print("emp-qual-std-dev")
  ;print(emp-qual-std-dev)
  ;print("work-asp-std-dev")
  ;print(work-asp-std-dev)
  ;print("work-qual-std-dev")
  ;print(work-qual-std-dev)
  
  ;;COMPUTE PEARSON INDEX
  ifelse prod-of-std-deviations = 0
  [set correlation-index 0]
  [set correlation-index covariance / prod-of-std-deviations]
  
  ;print("correlation-index")
  ;print(correlation-index)
  
  ;;COMPUTE PEARSON INDEX2
  ifelse prod-of-std-deviations2 = 0
  [set correlation-index2 0]
  [set correlation-index2 covariance2 / prod-of-std-deviations2]
  
  ;print("correlation-index2")
  ;print(correlation-index2)
  
  set average-correlation-index average-correlation-index + correlation-index
  set average-correlation-index2 average-correlation-index2 + correlation-index2
end
@#$#@#$#@
GRAPHICS-WINDOW
700
70
1220
611
25
-1
10.0
1
10
1
1
1
0
0
0
1
-25
25
0
50
1
1
1
ticks
30.0

BUTTON
30
50
93
83
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
125
50
188
83
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
205
15
377
48
n-employers
n-employers
2
50
15
1
1
NIL
HORIZONTAL

SLIDER
205
55
377
88
n-workers
n-workers
to-fill * n-employers
1000
200
2
1
NIL
HORIZONTAL

SLIDER
20
110
192
143
link-probability
link-probability
0
1
0
.01
1
NIL
HORIZONTAL

SLIDER
15
220
187
253
max-link-age
max-link-age
0
100
10
1
1
NIL
HORIZONTAL

PLOT
10
340
330
560
Number of hired workers
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"greens" 1.0 0 -10899396 true "" ""
"blues" 1.0 0 -13345367 true "" ""

PLOT
345
340
655
560
Group reputation
NIL
NIL
0.0
10.0
0.0
19.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"greens" 1.0 0 -10899396 true "" ""
"blues" 1.0 0 -13345367 true "" ""

MONITOR
570
95
685
144
NIL
discrimination-index
2
1
12

SLIDER
385
50
545
83
initial-reputation
initial-reputation
0
19
19
0.5
1
NIL
HORIZONTAL

MONITOR
570
205
690
254
NIL
variance-discrimination
2
1
12

MONITOR
570
150
690
199
NIL
mean-discrimination
2
1
12

TEXTBOX
25
95
175
113
network ties among employers
11
0.0
1

TEXTBOX
20
205
170
223
professional ties
11
0.0
1

SLIDER
200
220
372
253
friends-across
friends-across
0
1
0
0.01
1
NIL
HORIZONTAL

TEXTBOX
200
205
380
231
ties between employers and workers
11
0.0
1

SLIDER
205
100
377
133
to-fill
to-fill
1
20
6
1
1
NIL
HORIZONTAL

CHOOSER
15
155
153
200
network-type
network-type
"random" "star" "regular" "2 segments" "matrix entry"
0

SLIDER
385
160
545
193
group-gossip
group-gossip
0
1
0
0.01
1
NIL
HORIZONTAL

SLIDER
200
155
372
188
new-employment
new-employment
0
10
0
1
1
NIL
HORIZONTAL

MONITOR
570
260
677
305
pairwise similarity
pairwise-similarity
2
1
11

SLIDER
200
270
372
303
time-horizon
time-horizon
0
1000
100
1
1
NIL
HORIZONTAL

SLIDER
380
220
552
253
top-bias
top-bias
0
1
0
0.01
1
NIL
HORIZONTAL

SLIDER
380
270
552
303
bottom-bias
bottom-bias
0
1 - top-bias
0
0.01
1
NIL
HORIZONTAL

TEXTBOX
20
260
190
278
referral network among workers
11
0.0
1

SLIDER
20
275
192
308
referral-density
referral-density
0
0.48
0
0.001
1
NIL
HORIZONTAL

CHOOSER
170
575
317
620
worker-aspiration-level
worker-aspiration-level
"random" "quality correlated"
0

CHOOSER
385
100
547
145
aspiration-levels
aspiration-levels
"none" "average" "initial reputation" "randomly distributed" "quality correlated"
2

SLIDER
700
30
992
63
employer-quality-correlation-aspiration-level
employer-quality-correlation-aspiration-level
0
5
0
1
1
NIL
HORIZONTAL

BUTTON
125
15
188
48
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
820
395
922
440
NIL
correlation-index
3
1
11

PLOT
635
440
925
665
Correlation empl-quality worker-aspiration
NIL
NIL
0.0
25.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

MONITOR
660
395
817
440
NIL
average-correlation-index
17
1
11

PLOT
935
440
1235
665
Correlation empl-quality worker-quality
NIL
NIL
0.0
25.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SWITCH
20
580
147
613
dualmatching
dualmatching
0
1
-1000

MONITOR
1120
395
1232
440
NIL
correlation-index2
17
1
11

MONITOR
955
395
1117
440
NIL
average-correlation-index2\n
17
1
11

SLIDER
330
585
612
618
worker-quality-aspiration-correlation-index
worker-quality-aspiration-correlation-index
-0.999
0.999
0
0.001
1
NIL
HORIZONTAL

SWITCH
560
60
697
93
new-disc-index
new-disc-index
1
1
-1000

SLIDER
420
10
592
43
group-differences
group-differences
0
5
4
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This is the implementation of the model that is reported in the submission "High Standards Enhance Inequality in Idealized Labor Markets" to JASSS by Károly Takács and Flaminio Squazzoni.
This agent-based model aims to demonstrate that searching for the best options in the dual or one-sided matching process (dualmatching) in the labor market does not result in efficient and fair outcomes, as many economists believe. The model allows for the analysis of the consequences of purposeful selection choices of employers and acceptance decisions of applicants in a labor market with asymmetric information.


## HOW IT WORKS

This is a model of a simplified job market with unemployment, in which a fixed number of employers (n-employers) select employees (n-workers) for a restricted number of jobs (to-fill each).  Workers can accept or reject job offers. Employers hire workers for a fixed contract period of one year, during which the contract cannot be broken. Both employees and employers have an internal quality taken from a uniform random distribution with possible integer values of {0, 1, …, 19}. We assume that individual quality is fixed over time and does not improve by experience. We consider one recognizable trait for workers (color) and two social categories of this trait (blues and greens) with a fixed category membership.
While workers vary in their quality, characteristics of this variation are independent of color. Therefore, there is no statistical basis for discrimination. We assume that all employers are perfectly neutral: they do not belong to any of the workers’ social categories and do not have any initial bias towards them. We consider asymmetric information in the sense that employers are unable to observe the true individual quality of workers until they hire them, only their social category. Each employer form reputations about the two groups based on private experience with workers (blues, greens). Group reputations for each employer are calculated as the mean quality of the workers hired from that category in the previous m periods. 
Selection and acceptance decisions are based on (aspiration-i) of employers (taken from the distribution specified in the interface by (aspiration-levels); and on (aspiration) of workers. We assume that individual aspiration levels are fixed over time.
We consider a two-sided matching protocol in which employers give priority to previous workers whom they are satisfied with, i.e., to workers with a quality equal to or above (aspiration-i) and above (blues) and (greens). Employers do not re-hire anyone below these thresholds, because they rationally expect that a random worker has a higher quality than their current employee. If a selected worker has not worked there before, the contract is accepted automatically. If she worked there before, we assume she rejects the proposal if the firm’s (quality) is below her (aspiration). 
Hiring into job positions takes place sequentially. For each hiring, first, the selected employer checks previous employees and re-hires the one with the highest quality who is available, in case her quality is not below (aspiration-i) and is higher than (blues) and (greens). Re-hiring takes place only when the firm’s (quality) is equal to, or higher than the (aspiration) of the worker. Otherwise, the worker rejects the offer. Second, if there is no previous employee who satisfies the previous condition, an unemployed worker is picked randomly from a group with higher reputation. If group reputations are equal (e.g., at the outset), then an unemployed worker is randomly selected. The procedure is repeated until all vacancies are filled.   
The quality of employees is remembered by the employer from the last employment until (max-link-age) periods, irrespectively of the employee’s quality. For the sake of simplicity, we assume that the memory parameter (max-link-age) is the same for all employers. It is worth outlining that memory limitation is an assumption that prevents the system from running into a market with full information.
In addition, reputation mechanisms can be chosen using the (group-gossip), (top-bias) and (bottom-bias) variables. (group-gossip) modifies group reputation by the (blues) and (greens) of (professional ties). (group-gossip) describes the proportion to which group-reputation of friends determine the group-reputation of the given agent.
The (top-bias) and the (bottom-bias) variables have been introduced to capture cognitive biases. Their sum is a maximum of 1. A value of 1 for (top-bias) means that agents have a cognitive bias in creating their own group-reputation: they base this simply on the highest quality worker known from the given category. A value of 1 for (bottom-bias) means that agents have a cognitive bias in creating their own group-reputation: they base this simply on the lowest quality worker known from the given category. If both of them are 0, then there is no cognitive bias: agents take into account the mean values. The mean value is taken into consideration with a weight of 1 - (top-bias) - (bottom-bias).
If a worker is hired by an employer, she is unavailable to any other job. This means that in our model, there are externalities of selection choices. As a consequence, a shortage of high quality workers can quickly take place in the labor market.

## HOW TO USE IT

Use the interface to set up values of the major parameters. Push (setup) to initialize the network according to (network-type). Click on go to start one simulation. Use the behavioral space option to generate multiple simulation runs. 
As dependent measures, observe (average-discrimination), (adjusted-discrimination), (ave-mean-discrimination), (mean-discrimination), (labormarketsegregation-index) (variance-discrimination), (ave-var-discrimination), (new-disc-index), (pairwise similarity), (average-correlation-index), (correlation-index), (average-correlation-index2), (correlation-index2), and the plots of (Number of hired workers), (Group reputation), (Correlation empl-quality worker-aspiration) = (correlation-index), and (Correlation empl-quality worker-quality) = (correlation-index2).  
The macro level discrimination (average-discrimination) is the objective extent to which members from different groups are hired disproportionally. (average-discrimination) is distinguished from micro level discrimination (ave-mean-discrimination), which is the average extent to which individual employers stock up employees from the same group. The index is 0 in case of no inequalities in employment, and 1 when each job is filled with workers belonging to the same category. The micro level discrimination index (ave-mean-discrimination) is calculated similarly as the macro level index for each individual employer and then averaged over all employers.
The concentration of assertive workers in better jobs is measured by the Pearson correlation of obtained firm’s quality and assertiveness. Similarly, we used this measure to describe the concentration of good workers in good jobs. 

## THINGS TO NOTICE

The model demonstrates that inefficiency and inequality are inevitable consequences of seemingly optimizing behavior in the labor market. 
Notice the high level of discrimination indexes for any starting value.
Considering two groups of employees, our results show that inequality in employment always emerges due to the limited supply of high quality individuals, even in situations where there is no objective quality difference between average qualities and hiring decisions are not biased in favor of any of the groups. Inequalities are more exacerbated when employers have higher aspirations than if they do not strive for the best workers. We also found that assertive workers get higher quality jobs even if assertiveness is not correlated or even negatively correlated with internal quality. Our findings help to corroborate empirical findings that find higher employment discrepancy in high status jobs. 


## THINGS TO TRY

One could assume that employers have heterogeneous (aspiration-levels). We did not find any qualitative difference in the results if we relaxed the assumption of homogeneity. 
Among the control variables, (max-link-age) had a remarkable effect both on discrimination and on the correlation of assertiveness and firm’s quality. Longer memory enlarged the available pool of information and decreased discrimination, but it increased the extent of the assertiveness trap under any aspiration level and initial correlation of assertiveness and worker quality.


## EXTENDING THE MODEL

In addition to the parameters reported in the manuscript, this version introduces different reputation mechanisms.

## RELATED MODELS
Abdou M, Gilbert N (2009) Modelling the Emergence and Dynamics of Social and Workplace Segregation. Mind Society 8: 173-191.
Guerrero OA, Axtell RL (2013) Employment Growth through Labor Flow Networks. PLoS ONE 8(5): e60808. doi:10.1371/journal.pone.0060808
Stovel K, Fountain C (2009) Matching. In: Hedström, Peter and Bearman, Peter (eds.): The Oxford Handbook of Analytical Sociology. Oxford University Press.

## CREDITS AND REFERENCES

The code is written by Károly Takács.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="initialreputation" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="max-link-age">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="3"/>
      <value value="4.5"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityreputation" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="9"/>
    <steppedValueSet variable="link-probability" first="0" step="0.1" last="0.6"/>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityfinescale" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
      <value value="12"/>
      <value value="14"/>
      <value value="16"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <steppedValueSet variable="link-probability" first="0" step="0.1" last="0.6"/>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="numberofworkers" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
      <value value="200"/>
      <value value="400"/>
      <value value="600"/>
      <value value="800"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="10"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="networkshapes" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
      <value value="200"/>
      <value value="400"/>
      <value value="600"/>
      <value value="800"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="10"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densitytunedtoexperiment" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;none&quot;"/>
      <value value="&quot;initial reputation&quot;"/>
      <value value="&quot;randomly distributed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.3333333"/>
      <value value="0.5333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="nofworkers2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
      <value value="200"/>
      <value value="250"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
      <value value="500"/>
      <value value="600"/>
      <value value="800"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="networktype2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
      <value value="200"/>
      <value value="250"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
      <value value="500"/>
      <value value="600"/>
      <value value="800"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;regular&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="friendsacross" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;regular&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="competitionintensity" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <steppedValueSet variable="n-workers" first="75" step="5" last="150"/>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspirationrerun" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
      <value value="150"/>
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densitymemory" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="9.5"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="2"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="25"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="competitionaspiration" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <steppedValueSet variable="n-workers" first="75" step="5" last="150"/>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
      <value value="12"/>
      <value value="14"/>
      <value value="16"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.133"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="butterflyeffect" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.133"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groupgossip" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.133"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="group-gossip" first="0" step="0.1" last="0.7"/>
  </experiment>
  <experiment name="newemployment2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="120"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.133"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;regular&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-employment">
      <value value="0"/>
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="circlematrix" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.133333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;matrix entry&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="twocirclesmatrix" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.133333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;matrix entry&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="circlematrixreal" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.133333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;matrix entry&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="twocirclesonebridge" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1416666666666"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;matrix entry&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortruns" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.133"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="2"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortaspiration" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
      <value value="125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="10"/>
      <value value="12"/>
      <value value="14"/>
      <value value="16"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.133"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortrunslargemarket" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="1000"/>
      <value value="1250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortsegregation" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="10"/>
      <value value="12"/>
      <value value="14"/>
      <value value="16"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="2"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="timehorizon" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="9.5"/>
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.133"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="largemarket" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
      <value value="850"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="reputationmechanisms" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="acrossesrerun" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.013"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referraldensity" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="14"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.013"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="cognitivebiases" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Claudiocheck" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="6"/>
      <value value="12"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="acrossesrerun2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="memoryaspiration" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="25"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="acrossesrerun3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="timeaspiration" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="7"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="30"/>
      <value value="100"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="nworkerstofill" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="180"/>
      <value value="190"/>
      <value value="200"/>
      <value value="210"/>
      <value value="220"/>
      <value value="230"/>
      <value value="240"/>
      <value value="250"/>
      <value value="260"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralacrosses" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspirationrerun2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralaspiration" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspirationrerun3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortsegregation2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortsegregation3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspirationrerun4" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortsegregationcircle" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="320"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;matrix entry&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralacrosses2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.13333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groupgossip2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="1" step="2" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="group-gossip" first="0" step="0.05" last="0.5"/>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groupgossip3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="group-gossip" first="0" step="0.05" last="0.5"/>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspirationrerun5" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="butterflyeffect2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.05"/>
      <value value="0.133"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="memoryaspiration2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="25"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="nworkerstofill2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <metric>vardi-ini</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="180"/>
      <value value="190"/>
      <value value="200"/>
      <value value="210"/>
      <value value="220"/>
      <value value="230"/>
      <value value="240"/>
      <value value="250"/>
      <value value="260"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="memoryaspiration3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="25"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="timeaspiration2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="7"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="30"/>
      <value value="50"/>
      <value value="100"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="acrossesrerun4" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.08"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralacrosses3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>disc-ini</metric>
    <metric>meandi-ini</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.09"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralaspiration2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspiration100rerun" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspiration1000rerun" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groupgossip4" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
      <value value="0.08"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="group-gossip" first="0" step="0.05" last="0.5"/>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groupgossip22" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
      <value value="9"/>
      <value value="11"/>
      <value value="13"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="group-gossip" first="0" step="0.05" last="0.5"/>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="cognitivebiases2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0.13333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="nworkerstofill3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>adjusted-discrimination</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="190"/>
      <value value="200"/>
      <value value="210"/>
      <value value="220"/>
      <value value="230"/>
      <value value="240"/>
      <value value="250"/>
      <value value="260"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="top-bias">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-bias">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="shortsegregation4" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-gossip">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="densityaspiration100rerun2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0.1333333333333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
      <value value="&quot;regular&quot;"/>
      <value value="&quot;star&quot;"/>
      <value value="&quot;2 segments&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="referralaspiration22" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>ave-var-discrimination</metric>
    <metric>labormarketsegregation-index</metric>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.0020"/>
      <value value="0.0050"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment1-initialrep-random" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment2-random-random" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;randomly distributed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment3-qualityrelated-random" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-levels">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="employer-quality-correlation-aspiration-level">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment4-qualityrelated-qualityrelated" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-levels">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-quality-correlation-aspiration-level">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="employer-quality-correlation-aspiration-level">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment1BIS-initialrep-random" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="aspirationlevelforClaudioPaper" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="0" step="1" last="19"/>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-differences">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="assertivenesstrap" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-reputation" first="14" step="1" last="19"/>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="worker-quality-aspiration-correlation-index" first="-0.9" step="0.1" last="0.9"/>
  </experiment>
  <experiment name="heterogenousaspirations" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;randomly distributed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="worker-quality-aspiration-correlation-index" first="-0.9" step="0.1" last="0.9"/>
  </experiment>
  <experiment name="heterogenousmemory" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;randomly distributed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="worker-quality-aspiration-correlation-index" first="-0.9" step="0.3" last="0.9"/>
  </experiment>
  <experiment name="table2rerun" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-discrimination</metric>
    <metric>ave-mean-discrimination</metric>
    <metric>average-correlation-index</metric>
    <metric>average-correlation-index2</metric>
    <enumeratedValueSet variable="n-employers">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-link-age">
      <value value="3"/>
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-workers">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-reputation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="to-fill">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="aspiration-levels">
      <value value="&quot;initial reputation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="link-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="friends-across">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="referral-density">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-horizon">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="worker-aspiration-level">
      <value value="&quot;quality correlated&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="worker-quality-aspiration-correlation-index" first="-0.9" step="0.1" last="0.9"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
